//
//  GetSocialAction.h
//  GetSocial
//
//  Copyright © 2019 GetSocial BV. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/*!
 * Describes possible actions.
 */
typedef NSString *GetSocialActionType NS_EXTENSIBLE_STRING_ENUM;

/*!
 * Custom action.
 */
extern GetSocialActionType GetSocialActionCustom;

/*!
 * Open user's profile action.
 */
extern GetSocialActionType GetSocialActionOpenProfile;

/*!
 * Open an activity action.
 */
extern GetSocialActionType GetSocialActionOpenActivity;

/*!
 * Open invites UI action.
 */
extern GetSocialActionType GetSocialActionOpenInvites;

/*!
 * Open an url action.
 */
extern GetSocialActionType GetSocialActionOpenUrl;

/*!
 * Add a friend action.
 */
extern GetSocialActionType GetSocialActionAddFriend;

#pragma mark - GetSocial Action Data Key

/*!
 * Defines possible action keys.
 */
typedef NSString *GetSocialActionDataKey NS_EXTENSIBLE_STRING_ENUM;

#pragma mark - GetSocial OpenActivity Action Data Keys

/*!
 * GetSocialActionDataKey_OpenActivity_ActivityId and GetSocialActionDataKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialActionDataKey GetSocialActionDataKey_OpenActivity_ActivityId;

/*!
 * Optional. Can be present with GetSocialActionDataKey_OpenActivity_ActivityId only.
 */
extern GetSocialActionDataKey GetSocialActionDataKey_OpenActivity_CommentId;

/*!
 * GetSocialActionDataKey_OpenActivity_ActivityId and GetSocialActionDataKey_OpenActivity_FeedName are mutually exclusive.
 */
extern GetSocialActionDataKey GetSocialActionDataKey_OpenActivity_FeedName;

#pragma mark - GetSocial OpenProfile Action Data Keys

/*!
 * ID of user to be opened.
 */
extern GetSocialActionDataKey GetSocialActionDataKey_OpenProfile_UserId;

/*!
 * ID of user who wants to add as friend
 */
extern GetSocialActionDataKey GetSocialActionDataKey_AddFriend_UserId;

#pragma mark - GetSocial OpenUrl Action Data Keys

/*!
 * URL to be opened.
 */
extern GetSocialActionDataKey GetSocialActionDataKey_OpenUrl_Url;

/*!
 * Describes an action.
 */
@interface GetSocialAction : NSObject

/*!
 * Action to perform.
 * @return one of {@link GetSocialActionTypes}.
 */
@property (nonatomic, readonly) GetSocialActionType type;

/*!
 * Action data.
 * @return action data.
 */
@property (nonatomic, readonly) NSDictionary<GetSocialActionDataKey, NSString *> *data;

@end

NS_ASSUME_NONNULL_END
