//
//
// Copyright (c) 2019 GetSocial BV. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface GetSocialInstallPlatforms : NSObject

/*!
 * May contains not currently available platforms for the future compatibility.
 */
typedef NSString *GetSocialInstallPlatform NS_EXTENSIBLE_STRING_ENUM;

/*!
 * Install was performed via GetSocial Android or Android/Unity SDK.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Android;

/*!
 * Install was performed via GetSocial iOS or iOS/Unity SDK.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_iOS;

/*!
 * Install was performed via GetSocial HTTP API.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_API;

/*!
 * Install was performed via GetSocial Web SDK on Android device.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Web_Android;

/*!
 * Install was performed via GetSocial Web SDK on iOS device.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Web_iOS;

/*!
 * Install was performed via GetSocial Web SDK on desktop(Mac, Windows, Linux).
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Web_Desktop;

/*!
 * Install was performed via GetSocial Unity SDK on Windows.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Desktop_Windows;

/*!
 * Install was performed via GetSocial Unity SDK on Mac.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Desktop_Mac;

/*!
 * Install was performed via GetSocial Unity SDK on Linux.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Desktop_Linux;

/*!
 * Install was done by something not currently supported by GetSocial.
 */
extern GetSocialInstallPlatform GetSocialInstallPlatform_Other;

@end

